@@ -26,7 +26,7 @@ class RescissionWorkflow:
         target_admission_date: datetime = None,
         code_reason_rescission: int = None,
         activity_name: str = None,
-        rescission_time: datetime = None,
+        rescission_time: str = None,
         face_to_face_communication: str = None,
         email_corp_witness_1: str = None,
         email_corp_witness_2: str = None,
@@ -118,7 +118,7 @@ class RescissionWorkflow:
         target_admission_date: datetime = None,
         code_reason_rescission: int = None,
         activity_name: str = None,
-        rescission_time: datetime = None,
+        rescission_time: str = None,
         face_to_face_communication: str = None,
         email_corp_witness_1: str = None,
         email_corp_witness_2: str = None,
@@ -160,9 +160,7 @@ class RescissionWorkflow:
                 else None,
                 "code_reason_rescission": code_reason_rescission,
                 "activity_name": activity_name,
-                "rescission_time": rescission_time.strftime("%Y-%m-%d %H:%M:%S")
-                if rescission_time
-                else None,
+                "rescission_time": rescission_time,
                 "face_to_face_communication": face_to_face_communication,
                 "email_corp_witness_1": email_corp_witness_1,
                 "email_corp_witness_2": email_corp_witness_2,
